diff --git a/FL/Fl_Value_Slider.H b/FL/Fl_Value_Slider.H
index 462cdb4..b6b4e5c 100644
--- a/FL/Fl_Value_Slider.H
+++ b/FL/Fl_Value_Slider.H
@@ -34,6 +34,7 @@ class FL_EXPORT Fl_Value_Slider : public Fl_Slider {
     Fl_Font textfont_;
     Fl_Fontsize textsize_;
     Fl_Color textcolor_;
+    short textwidth_, textheight_;
 protected:
     void draw();
 public:
@@ -51,6 +52,14 @@ public:
     Fl_Color textcolor() const {return textcolor_;}
     /**    Sets the color of the text in the value box.  */
     void textcolor(Fl_Color s) {textcolor_ = s;}
+    /**    Sets the width of the text box in pixels (horizontal mode only).  */
+    void textwidth(int s) {textwidth_ = (short)s;}
+    /**    Gets the width of the text box in pixels (horizontal mode only).  */
+    int textwidth() const {return(textwidth_);}
+    /**    Sets the height of the text box in pixels (vertical mode only).  */
+    void textheight(int s) {textheight_ = (short)s;}
+    /**    Gets the height of the text box in pixels (vertical mode only).  */
+    int textheight() const {return(textheight_);}
 };
 
 #endif
diff --git a/src/Fl_Value_Slider.cxx b/src/Fl_Value_Slider.cxx
index ac06271..b2567b9 100644
--- a/src/Fl_Value_Slider.cxx
+++ b/src/Fl_Value_Slider.cxx
@@ -32,15 +32,17 @@ Fl_Value_Slider::Fl_Value_Slider(int X, int Y, int W, int H, const char*l)
   textfont_ = FL_HELVETICA;
   textsize_ = 10;
   textcolor_ = FL_FOREGROUND_COLOR;
+  textwidth_ = 35;
+  textheight_ = 25;
 }
 
 void Fl_Value_Slider::draw() {
   int sxx = x(), syy = y(), sww = w(), shh = h();
   int bxx = x(), byy = y(), bww = w(), bhh = h();
   if (horizontal()) {
-    bww = 35; sxx += 35; sww -= 35;
+    bww = textwidth(); sxx += textwidth(); sww -= textwidth();
   } else {
-    syy += 25; bhh = 25; shh -= 25;
+    syy += textheight(); bhh = textheight(); shh -= textheight();
   }
   if (damage()&FL_DAMAGE_ALL) draw_box(box(),sxx,syy,sww,shh,color());
   Fl_Slider::draw(sxx+Fl::box_dx(box()),
@@ -62,9 +64,9 @@ int Fl_Value_Slider::handle(int event) {
   }
   int sxx = x(), syy = y(), sww = w(), shh = h();
   if (horizontal()) {
-    sxx += 35; sww -= 35;
+    sxx += textwidth(); sww -= textwidth();
   } else {
-    syy += 25; shh -= 25;
+    syy += textheight(); shh -= textheight();
   }
   return Fl_Slider::handle(event,
 			   sxx+Fl::box_dx(box()),
